@@ -74,7 +74,7 @@ struct session_info_st *find_session_info(uint32_t sessionid, int createIfNotExi
 		if (ret) {
 			ret->sessionid = sessionid;
 			ret->imgptr = NULL;
-			ret->last_used_time = 0;
+			ret->last_used_time = time(NULL);
 			ret->lastx = 65535;
 			ret->lasty = 65535;
 			ret->lastcnt = 0;
@@ -102,12 +102,10 @@ void cleanup_sessions(int session_age_limit) {
 		next = chk_session_list->_next;
 
 		if (chk_session_list->last_used_time < expire_time) {
-			if (chk_session_list) {
-				if (chk_session_list->imgptr) {
-					gdImageDestroy(chk_session_list->imgptr);
-				}
-				pthread_mutex_destroy(&chk_session_list->imgptr_mut);
+			if (chk_session_list->imgptr) {
+				gdImageDestroy(chk_session_list->imgptr);
 			}
+			pthread_mutex_destroy(&chk_session_list->imgptr_mut);
 
 			if (session_list == chk_session_list) {
 				session_list = next;
@@ -265,6 +263,7 @@ THREAD_FUNCTION_RETURN handle_connection(void *arg) {
 	size_t bytes_to_send, bytes_to_read;
 	char reply_buf[1024], *reply_buf_p, copy_buf[8192];
 	char *http_reply_msg, *http_reply_body, *http_reply_body_file, *http_reply_content_type;
+	int pthdetach;
 	int http_reply_code, http_reply_content_length = 0;
 	int reply_buf_len;
 	int stat_ret, event_ret;
@@ -622,7 +621,12 @@ THREAD_FUNCTION_RETURN handle_connection(void *arg) {
 	close(fd);
 	free(fd_p);
 
-	pthread_detach(pthread_self());
+	pthdetach = pthread_detach(pthread_self());
+#ifndef NDEBUG
+	if (pthdetach != 0) {
+		printf("[%llx] Error detaching thread: pthread_detach() returns %i\n", (unsigned long long) pthread_self(), pthdetach);
+	}
+#endif
 
 	return((THREAD_FUNCTION_RETURN) 0);
 }
